# Module Interfaces Simple SNMPv3

## Description

MIBs used: IF-MIB

## Overview

This is a module based on the "TTemplate Module Interfaces Simple SNMPv2" module. For correct use, you need to define the macro "{$SNMP\_SECNAME\_CONTEXT}", this macro is also used in the rest of my templates using SNMPv3. I do not use authentication and encryption in my templates, which corresponds to security level = noAuthNoPriv



## Author

Alexey Glotkin

## Macros used

|Name|Description|Default|Type|
|----|-----------|-------|----|
|{$IFCONTROL}|<p>-</p>|`1`|Text macro|
|{$IF_ERRORS_WARN}|<p>-</p>|`2`|Text macro|
|{$IF_UTIL_MAX}|<p>-</p>|`95`|Text macro|


## Template links

There are no template links in this template.

## Discovery rules

|Name|Description|Type|Key and additional info|
|----|-----------|----|----|
|Network Interfaces Discovery|<p>Discovering interfaces from IF-MIB. Interfaces with down(2) Administrative Status are not discovered.</p>|`SNMP agent`|net.if.discovery<p>Update: 3600</p>|


## Items collected

|Name|Description|Type|Key and additional info|
|----|-----------|----|----|
|Interface {#IFDESCR}: Inbound pkts discarded|<p>MIB: IF-MIB The number of inbound packets which were chosen to be discarded even though no errors had been detected to prevent their being deliverable to a higher-layer protocol. One possible reason for discarding such a packet could be to free up buffer space. Discontinuities in the value of this counter can occur at re-initialization of the management system, and at other times as indicated by the value of ifCounterDiscontinuityTime.</p>|`SNMP agent`|net.if.in.discards[ifInDiscards.{#SNMPINDEX}]<p>Update: 300</p><p>LLD</p>|
|Interface {#IFDESCR}: Inbound non-unicast pkts|<p>MIB: IF-MIB The number of non-unicast (i.e., subnetwork- broadcast or subnetwork-multicast) packets delivered to a higher-layer protocol.</p>|`SNMP agent`|net.if.in.discards[ifInNUcastPkts.{#SNMPINDEX}]<p>Update: 180</p><p>LLD</p>|
|Interface {#IFDESCR}: Inbound unicast pkts|<p>MIB: IF-MIB The number of subnetwork-unicast packets delivered to a higher-layer protocol.</p>|`SNMP agent`|net.if.in.discards[ifInUcastPkts.{#SNMPINDEX}]<p>Update: 180</p><p>LLD</p>|
|Interface {#IFDESCR}: Inbound pkts with errors|<p>MIB: IF-MIB For packet-oriented interfaces, the number of inbound packets that contained errors preventing them from being deliverable to a higher-layer protocol. For character-oriented or fixed-length interfaces, the number of inbound transmission units that contained errors preventing them from being deliverable to a higher-layer protocol. Discontinuities in the value of this counter can occur at re-initialization of the management system, and at other times as indicated by the value of ifCounterDiscontinuityTime.</p>|`SNMP agent`|net.if.in.errors[ifInErrors.{#SNMPINDEX}]<p>Update: 300</p><p>LLD</p>|
|Interface {#IFDESCR}: Bits received|<p>MIB: IF-MIB The total number of octets received on the interface,including framing characters. Discontinuities in the value of this counter can occurat re-initialization of the management system, and atother times as indicated by the value of ifCounterDiscontinuityTime.</p>|`SNMP agent`|net.if.in[ifInOctets.{#SNMPINDEX}]<p>Update: 180</p><p>LLD</p>|
|Interface {#IFDESCR}: Outbound pkts discarded|<p>MIB: IF-MIB The number of outbound packets which were chosen to be discarded even though no errors had been detected to prevent their being deliverable to a higher-layer protocol. One possible reason for discarding such a packet could be to free up buffer space. Discontinuities in the value of this counter can occur at re-initialization of the management system, and at other times as indicated by the value of ifCounterDiscontinuityTime.</p>|`SNMP agent`|net.if.out.discards[ifOutDiscards.{#SNMPINDEX}]<p>Update: 300</p><p>LLD</p>|
|Interface {#IFDESCR}: Outbound pkts with errors|<p>MIB: IF-MIB For packet-oriented interfaces, the number of outbound packets that contained errors preventing them from being deliverable to a higher-layer protocol. For character-oriented or fixed-length interfaces, the number of outbound transmission units that contained errors preventing them from being deliverable to a higher-layer protocol. Discontinuities in the value of this counter can occur at re-initialization of the management system, and at other times as indicated by the value of ifCounterDiscontinuityTime.</p>|`SNMP agent`|net.if.out.errors[ifOutErrors.{#SNMPINDEX}]<p>Update: 300</p><p>LLD</p>|
|Interface {#IFDESCR}: Outbound non-unicast pkts|<p>MIB: IF-MIB The total number of packets that higher-level protocols requested be transmitted to a non- unicast (i.e., a subnetwork-broadcast or subnetwork-multicast) address, including those that were discarded or not sent.</p>|`SNMP agent`|net.if.out[ifOutNUcastPkts.{#SNMPINDEX}]<p>Update: 180</p><p>LLD</p>|
|Interface {#IFDESCR}: Bits sent|<p>MIB: IF-MIB The total number of octets transmitted out of the interface, including framing characters. Discontinuities in the value of this counter can occurat re-initialization of the management system, and at other times as indicated by the value of ifCounterDiscontinuityTime.</p>|`SNMP agent`|net.if.out[ifOutOctets.{#SNMPINDEX}]<p>Update: 180</p><p>LLD</p>|
|Interface {#IFDESCR}: Outbound unicast pkts|<p>MIB: IF-MIB The total number of packets that higher-level protocols requested be transmitted to a subnetwork-unicast address, including those that were discarded or not sent.</p>|`SNMP agent`|net.if.out[ifOutUcastPkts.{#SNMPINDEX}]<p>Update: 180</p><p>LLD</p>|
|Interface {#IFDESCR}: Speed|<p>MIB: IF-MIB An estimate of the interface's current bandwidth in bits per second. For interfaces which do not vary in bandwidth or for those where no accurate estimation can be made, this object should contain the nominal bandwidth. If the bandwidth of the interface is greater than the maximum value reportable by this object then this object should report its maximum value (4,294,967,295) and ifHighSpeed must be used to report the interace's speed. For a sub-layer which has no concept of bandwidth, this object should be zero.</p>|`SNMP agent`|net.if.speed[ifSpeed.{#SNMPINDEX}]<p>Update: 300</p><p>LLD</p>|
|Interface {#IFDESCR}: Operational status|<p>MIB: IF-MIB The current operational state of the interface. - The testing(3) state indicates that no operational packet scan be passed - If ifAdminStatus is down(2) then ifOperStatus should be down(2) - If ifAdminStatus is changed to up(1) then ifOperStatus should change to up(1) if the interface is ready to transmit and receive network traffic - It should change todormant(5) if the interface is waiting for external actions (such as a serial line waiting for an incoming connection) - It should remain in the down(2) state if and only if there is a fault that prevents it from going to the up(1) state - It should remain in the notPresent(6) state if the interface has missing(typically, hardware) components.</p>|`SNMP agent`|net.if.status[ifOperStatus.{#SNMPINDEX}]<p>Update: 60</p><p>LLD</p>|
|Interface {#IFDESCR}: Interface type|<p>MIB: IF-MIB The type of interface. Additional values for ifType are assigned by the Internet Assigned NumbersAuthority (IANA), through updating the syntax of the IANAifType textual convention.</p>|`SNMP agent`|net.if.type[ifType.{#SNMPINDEX}]<p>Update: 3600</p><p>LLD</p>|
|Interface {#IFDESCR}: MAC Address|<p>MIB: IF-MIB The interface's address at the protocol layer immediately `below' the network layer in the protocol stack. For interfaces which do not have such an address (e.g., a serial line), this object should contain an octet string of zero length.</p>|`SNMP agent`|net.if[ifPhysAddress.{#SNMPINDEX}]<p>Update: 1h</p><p>LLD</p>|


## Triggers

|Name|Description|Expression|Priority|
|----|-----------|----------|--------|
|Interface {#IFDESCR}: Ethernet has changed to lower speed than it was before|<p>Last value: {ITEM.LASTVALUE1}. This Ethernet connection has transitioned down from its known maximum speed. This might be a sign of autonegotiation issues. Ack to close.</p>|<p>**Expression**: change(/Module Interfaces Simple SNMPv3/net.if.speed[ifSpeed.{#SNMPINDEX}])<0 and last(/Module Interfaces Simple SNMPv3/net.if.speed[ifSpeed.{#SNMPINDEX}])>0 and ( last(/Module Interfaces Simple SNMPv3/net.if.type[ifType.{#SNMPINDEX}])=6 or last(/Module Interfaces Simple SNMPv3/net.if.type[ifType.{#SNMPINDEX}])=7 or last(/Module Interfaces Simple SNMPv3/net.if.type[ifType.{#SNMPINDEX}])=11 or last(/Module Interfaces Simple SNMPv3/net.if.type[ifType.{#SNMPINDEX}])=62 or last(/Module Interfaces Simple SNMPv3/net.if.type[ifType.{#SNMPINDEX}])=69 or last(/Module Interfaces Simple SNMPv3/net.if.type[ifType.{#SNMPINDEX}])=117 ) and (last(/Module Interfaces Simple SNMPv3/net.if.status[ifOperStatus.{#SNMPINDEX}])<>2) </p><p>**Recovery expression**: (change(/Module Interfaces Simple SNMPv3/net.if.speed[ifSpeed.{#SNMPINDEX}])>0 and last(/Module Interfaces Simple SNMPv3/net.if.speed[ifSpeed.{#SNMPINDEX}],#2)>0) or (last(/Module Interfaces Simple SNMPv3/net.if.status[ifOperStatus.{#SNMPINDEX}])=2)</p>|information|
|Interface {#IFDESCR}: High bandwidth usage >{$IF_UTIL_MAX:"{#IFNAME}"}%|<p>Last value: {ITEM.LASTVALUE1}.</p>|<p>**Expression**: (avg(/Module Interfaces Simple SNMPv3/net.if.in[ifInOctets.{#SNMPINDEX}],15m)>(95/100)*last(/Module Interfaces Simple SNMPv3/net.if.speed[ifSpeed.{#SNMPINDEX}]) or avg(/Module Interfaces Simple SNMPv3/net.if.out[ifOutOctets.{#SNMPINDEX}],15m)>(95/100)*last(/Module Interfaces Simple SNMPv3/net.if.speed[ifSpeed.{#SNMPINDEX}])) and last(/Module Interfaces Simple SNMPv3/net.if.speed[ifSpeed.{#SNMPINDEX}])>0</p><p>**Recovery expression**: avg(/Module Interfaces Simple SNMPv3/net.if.in[ifInOctets.{#SNMPINDEX}],15m)<((95-3)/100)*last(/Module Interfaces Simple SNMPv3/net.if.speed[ifSpeed.{#SNMPINDEX}]) and avg(/Module Interfaces Simple SNMPv3/net.if.out[ifOutOctets.{#SNMPINDEX}],15m)<((95-3)/100)*last(/Module Interfaces Simple SNMPv3/net.if.speed[ifSpeed.{#SNMPINDEX}])</p>|warning|
|Interface {#IFDESCR}: High error rate|<p>Last value: {ITEM.LASTVALUE1}.</p>|<p>**Expression**: avg(/Module Interfaces Simple SNMPv3/net.if.in.errors[ifInErrors.{#SNMPINDEX}],5m)>2 or avg(/Module Interfaces Simple SNMPv3/net.if.out.errors[ifOutErrors.{#SNMPINDEX}],5m)>2</p><p>**Recovery expression**: avg(/Module Interfaces Simple SNMPv3/net.if.in.errors[ifInErrors.{#SNMPINDEX}],5m)<2-2 and avg(/Module Interfaces Simple SNMPv3/net.if.out.errors[ifOutErrors.{#SNMPINDEX}],5m)<2-2</p>|warning|
|Interface {#IFDESCR}: Link down|<p>Last value: {ITEM.LASTVALUE1}. Interface is down</p>|<p>**Expression**: 1=1 and (last(/Module Interfaces Simple SNMPv3/net.if.status[ifOperStatus.{#SNMPINDEX}])=2 and (last(/Module Interfaces Simple SNMPv3/net.if.status[ifOperStatus.{#SNMPINDEX}],#1)<>last(/Module Interfaces Simple SNMPv3/net.if.status[ifOperStatus.{#SNMPINDEX}],#2))=1)</p><p>**Recovery expression**: </p>|average|
|Interface {#IFDESCR}: Ethernet has changed to lower speed than it was before (LLD)|<p>Last value: {ITEM.LASTVALUE1}. This Ethernet connection has transitioned down from its known maximum speed. This might be a sign of autonegotiation issues. Ack to close.</p>|<p>**Expression**: change(/Module Interfaces Simple SNMPv3/net.if.speed[ifSpeed.{#SNMPINDEX}])<0 and last(/Module Interfaces Simple SNMPv3/net.if.speed[ifSpeed.{#SNMPINDEX}])>0 and ( last(/Module Interfaces Simple SNMPv3/net.if.type[ifType.{#SNMPINDEX}])=6 or last(/Module Interfaces Simple SNMPv3/net.if.type[ifType.{#SNMPINDEX}])=7 or last(/Module Interfaces Simple SNMPv3/net.if.type[ifType.{#SNMPINDEX}])=11 or last(/Module Interfaces Simple SNMPv3/net.if.type[ifType.{#SNMPINDEX}])=62 or last(/Module Interfaces Simple SNMPv3/net.if.type[ifType.{#SNMPINDEX}])=69 or last(/Module Interfaces Simple SNMPv3/net.if.type[ifType.{#SNMPINDEX}])=117 ) and (last(/Module Interfaces Simple SNMPv3/net.if.status[ifOperStatus.{#SNMPINDEX}])<>2) </p><p>**Recovery expression**: (change(/Module Interfaces Simple SNMPv3/net.if.speed[ifSpeed.{#SNMPINDEX}])>0 and last(/Module Interfaces Simple SNMPv3/net.if.speed[ifSpeed.{#SNMPINDEX}],#2)>0) or (last(/Module Interfaces Simple SNMPv3/net.if.status[ifOperStatus.{#SNMPINDEX}])=2)</p>|information|
|Interface {#IFDESCR}: High bandwidth usage >{$IF_UTIL_MAX:"{#IFNAME}"}% (LLD)|<p>Last value: {ITEM.LASTVALUE1}.</p>|<p>**Expression**: (avg(/Module Interfaces Simple SNMPv3/net.if.in[ifInOctets.{#SNMPINDEX}],15m)>(95/100)*last(/Module Interfaces Simple SNMPv3/net.if.speed[ifSpeed.{#SNMPINDEX}]) or avg(/Module Interfaces Simple SNMPv3/net.if.out[ifOutOctets.{#SNMPINDEX}],15m)>(95/100)*last(/Module Interfaces Simple SNMPv3/net.if.speed[ifSpeed.{#SNMPINDEX}])) and last(/Module Interfaces Simple SNMPv3/net.if.speed[ifSpeed.{#SNMPINDEX}])>0</p><p>**Recovery expression**: avg(/Module Interfaces Simple SNMPv3/net.if.in[ifInOctets.{#SNMPINDEX}],15m)<((95-3)/100)*last(/Module Interfaces Simple SNMPv3/net.if.speed[ifSpeed.{#SNMPINDEX}]) and avg(/Module Interfaces Simple SNMPv3/net.if.out[ifOutOctets.{#SNMPINDEX}],15m)<((95-3)/100)*last(/Module Interfaces Simple SNMPv3/net.if.speed[ifSpeed.{#SNMPINDEX}])</p>|warning|
|Interface {#IFDESCR}: High error rate (LLD)|<p>Last value: {ITEM.LASTVALUE1}.</p>|<p>**Expression**: avg(/Module Interfaces Simple SNMPv3/net.if.in.errors[ifInErrors.{#SNMPINDEX}],5m)>2 or avg(/Module Interfaces Simple SNMPv3/net.if.out.errors[ifOutErrors.{#SNMPINDEX}],5m)>2</p><p>**Recovery expression**: avg(/Module Interfaces Simple SNMPv3/net.if.in.errors[ifInErrors.{#SNMPINDEX}],5m)<2-2 and avg(/Module Interfaces Simple SNMPv3/net.if.out.errors[ifOutErrors.{#SNMPINDEX}],5m)<2-2</p>|warning|
|Interface {#IFDESCR}: Link down (LLD)|<p>Last value: {ITEM.LASTVALUE1}. Interface is down</p>|<p>**Expression**: 1=1 and (last(/Module Interfaces Simple SNMPv3/net.if.status[ifOperStatus.{#SNMPINDEX}])=2 and (last(/Module Interfaces Simple SNMPv3/net.if.status[ifOperStatus.{#SNMPINDEX}],#1)<>last(/Module Interfaces Simple SNMPv3/net.if.status[ifOperStatus.{#SNMPINDEX}],#2))=1)</p><p>**Recovery expression**: </p>|average|
